get_mua: Get Mutation info

Description Usage Arguments Value Examples

View source: R/format_data.R

Description

Get Mutation info

Usage

1
get_mua(data_path, index, bind = TRUE)

Arguments

data_path

File name in working directory, path to file that contain Gene name, mutation and sample id.

index

A vector of column names to keep. Just look like c(gene = col1_index, mutation = col2_index, sample_id = col3_index). Index can be column name or the number index

bind

TRUE bind gene and mutation

Value

The dt with id(gene-mutation) and sample id info

Examples

1
2
3
4
5
## Not run: 
index <- c(gene = "Hugo_Symbol", mutation = "HGVSp_Short", sample_id = "Tumor_Sample_Barcode")
dt <- get_mutation("data_path", index)

## End(Not run)

zhchenyang/tcga documentation built on Dec. 23, 2021, 9:18 p.m.