get_sample_info: Get the sample info

Description Usage Arguments Value Examples

View source: R/format_data.R

Description

Get the sample info

Usage

1
get_sample_info(data_path, index, bind = FALSE)

Arguments

data_path

File name in working directory, path to file that contain sample id, stage...

index

A vector of column names to keep. Just look like c(sample_id = col_index, race = col_index2, stages = col_index3). Index can be column name or the number index

bind

FALSE useless

Value

sample info

Examples

1
2
3
4
5
## Not run: 
index <- c(sample_id = "submitter_id", race = "race", stages = "tumor_stage")
sample_info <- get_sample_info("data_path", index)

## End(Not run)

zhchenyang/tcga documentation built on Dec. 23, 2021, 9:18 p.m.