Description Usage Arguments Value Examples
Get Mutation info
1 |
data_path |
File name in working directory, path to file that contain Gene name, mutation and sample id. |
index |
A vector of column names to keep. Just look like c(gene = col1_index, mutation = col2_index, sample_id = col3_index). Index can be column name or the number index |
bind |
TRUE bind gene and mutation |
The dt with id(gene-mutation) and sample id info
1 2 3 4 5 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.