Description Usage Arguments Value Examples
Get the sample info
1 | get_sample_info(data_path, index, bind = FALSE)
|
data_path |
File name in working directory, path to file that contain sample id, stage... |
index |
A vector of column names to keep. Just look like c(sample_id = col_index, race = col_index2, stages = col_index3). Index can be column name or the number index |
bind |
FALSE useless |
sample info
1 2 3 4 5 | ## Not run:
index <- c(sample_id = "submitter_id", race = "race", stages = "tumor_stage")
sample_info <- get_sample_info("data_path", index)
## End(Not run)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.